@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -210,7 +206,6 @@ public class LocaleNames_ee extends OpenListResourceBundle {
             { "IL", "Israel nutome" },
             { "IM", "Aisle of Man nutome" },
             { "IN", "India nutome" },
-            { "IO", "Britaint\u0254wo \u0192e india \u0192udome nutome" },
             { "IQ", "iraqduk\u0254" },
             { "IR", "Iran nutome" },
             { "IS", "Aiseland nutome" },
@@ -248,7 +243,6 @@ public class LocaleNames_ee extends OpenListResourceBundle {
             { "MF", "Saint Martin nutome" },
             { "MG", "Madagaska nutome" },
             { "MH", "Marshal \u0192udomekpowo nutome" },
-            { "MK", "Makedonia nutome" },
             { "ML", "Mali nutome" },
             { "MM", "Myanmar (Burma) nutome" },
             { "MN", "Mongolia nutome" },
@@ -606,7 +600,6 @@ public class LocaleNames_ee extends OpenListResourceBundle {
             { "type.co.stroke", "stroke \u0256o\u0256om\u0254 nu" },
             { "type.co.unihan", "\u0256o\u0256om\u0254nut\u0254x\u025b man\u0254\u014bu stroke \u0192e \u0256o\u0256o nu" },
             { "type.ca.chinese", "chinat\u0254wo \u0192e kalenda" },
-            { "type.ca.islamic", "islam sub\u0254lawo \u0192e kalenda" },
             { "type.ca.persian", "persiat\u0254wo \u0192e kalenda" },
             { "type.co.big5han", "blema chinat\u0254wo \u0192e \u0256o\u0256om\u0254 nu" },
             { "type.nu.arabext", "india \u0192e arabia digitwo dzi yiyi" },
@@ -619,8 +612,6 @@ public class LocaleNames_ee extends OpenListResourceBundle {
             { "type.ca.buddhist", "buddha sub\u0254lawo \u0192e kalenda" },
             { "type.ca.ethiopic", "ethiopiat\u0254wo \u0192e kalenda" },
             { "type.ca.japanese", "japant\u0254wo \u0192e kalenda" },
-            { "type.co.reformed", "nugbugb\u0254to\u0256o \u0192e \u0256o\u0256om\u0254 nu" },
-            { "type.co.standard", "standard" },
             { "type.nu.fullwide", "digit kekeme blibot\u0254wo" },
             { "type.nu.romanlow", "romat\u0254wo \u0192e numeral suet\u0254wo" },
             { "type.ca.gregorian", "Gregorian kalenda" },
@@ -628,7 +619,6 @@ public class LocaleNames_ee extends OpenListResourceBundle {
             { "type.co.phonebook", "fonegbal\u1ebd me \u0256o\u0256om\u0254 nu" },
             { "type.co.dictionary", "nu\u0256o\u0256o \u0256e nyag\u0254me\u0256egbal\u1ebd \u0192e \u0256o\u0256om\u0254 nu" },
             { "type.co.traditional", "blema \u0256o\u0256om\u0254 nu" },
-            { "type.ca.islamic-civil", "islam sub\u0254lawo \u0192e sivil kalenda" },
             { "type.ca.ethiopic-amete-alem", "ethiopia amate alemt\u0254wo \u0192e kalenda" },
         };
         return data;
